@@ -73,7 +73,7 @@ def check(cert, key):
             error_flag = 1
 
         # check certificate date
-        cert_data = open(cert, 'r').read()
+        cert_data = readFile(cert)
         certobj = OpenSSL.crypto.load_certificate(
             OpenSSL.SSL.FILETYPE_PEM, cert_data)
         certobj.get_notBefore()
@@ -247,7 +247,7 @@ def create_request(server_cert, cert_path, data_path, certbase,
         os.chmod(key, 0600)
 
     ip, mac, client_type = get_ip_mac_type()
-    data = open(client_req_file).read()
+    data = readFile(client_req_file)
 
     req_id = post_request.serv_post_client_request(
         data, data_path, ip, mac, client_type, certbase, cert_path)
@@ -279,7 +279,7 @@ def clear_localuser_certificates(certbase):
     Удалить все пользовательские сертификаты, создаваемые для локальных
     пользователей
     """
-    certdata = readFile(certbase, grab=True)
+    certdata = readFileEx(certbase, grab=True)
     certdn = os.path.dirname(certbase)
     # оставляем только сертификаты, которые не содержат отметки
     # для какого локального пользователя они созданы
@@ -317,7 +317,7 @@ def get_certificate(cert_path, data_path, certbase, client_cert_path,
     if not os.path.exists(req_file):
         print _('Request %s not found') % req_file
         return 1
-    request = open(req_file).read()
+    request = readFile(req_file)
     md5 = hashlib.md5()
     md5.update(request)
     md5sum = md5.hexdigest()
@@ -367,7 +367,7 @@ def get_certificate(cert_path, data_path, certbase, client_cert_path,
         clVars.flIniFile()
         system_ca_db = clVars.Get('cl_glob_root_cert')
         if os.path.exists(system_ca_db):
-            if ca_root in open(system_ca_db, 'r').read():
+            if ca_root in readFile(system_ca_db):
                 return 0
 
         ca_dir = os.path.join(client_cert_path, 'ca')
