@@ -127,7 +127,8 @@ class CommonMethods(MethodsInterface):
                 continue
             elif answ == "use new":
                 try:
-                    open(orig, 'w').write(readFile(data[i_cfgname]))
+                    with open(orig, 'w') as fd:
+                        fd.write(readFile(data[i_cfgname]))
                     os.unlink(data[i_cfgname])
                     if filesApply:
                         try:
@@ -1369,7 +1370,7 @@ class CoreWsdl(CoreServiceInterface):
         cert_file = data_path + '/client_certs/%s.crt' % str(cert_id)
         if not os.path.exists(cert_file):
             return ["-1"]
-        cert = open(cert_file, 'r').read()
+        cert = readFile(cert_file)
 
         # try:
         import OpenSSL
@@ -1508,28 +1509,27 @@ def create_symlink(data_path, old_data_path):
             print (_("cannot create directory %s")
                    % (os.path.join(data_path, 'conf')))
     if os.path.exists(old_symlinks_file) and not os.path.exists(symlinks_file):
-        open(symlinks_file, 'w').write(open(old_symlinks_file).read())
+        with open(symlinks_file, 'w') as fd:
+            fd.write(readFile(old_symlinks_file))
         os.unlink(old_symlinks_file)
-    fd = open(symlinks_file, 'a')
-    for link in meths:
-        link_path = os.path.join(path_to_link, link)
-        if os.path.islink(link_path):
-            continue
-        if os.path.isfile(link_path):
-            red = '\033[31m * \033[0m'
-            print red + link_path + _(' is a file, not a link!')
-            continue
-        try:
-            if (os.path.islink(link_path) and
-                        os.readlink(link_path) != core_wrapper):
-                os.unlink(link_path)
-                print "REFRESH OLD", link_path
-            os.symlink(core_wrapper, link_path)
-            fd.write(link_path + '\n')
-        except OSError, e:
-            print e.message
-        print _('Symlink %s created') % link_path
-    fd.close()
+    with open(symlinks_file, 'a') as fd:
+        for link in meths:
+            link_path = os.path.join(path_to_link, link)
+            if os.path.islink(link_path):
+                continue
+            if os.path.isfile(link_path):
+                red = '\033[31m * \033[0m'
+                print red + link_path + _(' is a file, not a link!')
+                continue
+            try:
+                if (os.path.islink(link_path) and
+                            os.readlink(link_path) != core_wrapper):
+                    os.unlink(link_path)
+                os.symlink(core_wrapper, link_path)
+                fd.write(link_path + '\n')
+            except OSError, e:
+                print e.message
+            print _('Symlink %s created') % link_path
 
     temp_text_file = ''
     for line in readLinesFile(symlinks_file):
